
# q-expansion of newform 2916.2.e.d, downloaded from the LMFDB on 23 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2916
weight = 2
poly_data = [19683, -39366, 52488, -48114, 37179, -25515, 17577, -12150, 8100, -4941, 2700, -1350, 651, -315, 153, -66, 24, -6, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-22362075, 29804436, -33984522, 24028812, -16981245, 11005146, -7905303, 5463342, -3352851, 1842579, -886086, 413877, -207198, 99036, -47439, 14277, -3732, -53], 391473], [[26585172, -31599963, 31656096, -20999574, 14304438, -9707445, 6970266, -4749786, 2777688, -1450341, 684600, -316695, 166824, -77748, 34479, -8607, 1712, 173], 391473], [[-131220, 126846, -131949, 77274, -55161, 36126, -26136, 17685, -9864, 5076, -2265, 1038, -576, 249, -117, 18, -5, -2], 2187], [[-216513, 273375, -305451, 216513, -151632, 100440, -71064, 49221, -30069, 16578, -8067, 3768, -1908, 903, -432, 135, -37, 2], 2187], [[-69984, 104976, -121014, 97686, -69579, 47061, -32481, 22626, -14337, 8208, -4215, 2001, -981, 471, -225, 84, -25, 4], 2187], [[21310128, -28621269, 31495716, -24040233, 16966260, -11529459, 7959519, -5527440, 3430656, -1928835, 972537, -459726, 229050, -108843, 51078, -18252, 5258, -821], 391473], [[-113724, 166212, -194643, 151632, -108864, 73143, -51138, 35748, -22509, 12852, -6528, 3102, -1530, 732, -351, 126, -37, 5], 2187], [[-33534, 53946, -60750, 48843, -34344, 23355, -16227, 11295, -7173, 4086, -2088, 996, -486, 237, -111, 42, -12, 2], 729], [[-114453, 145800, -161838, 117126, -83079, 55755, -39294, 27171, -16647, 9243, -4566, 2154, -1086, 513, -242, 78, -22, 2], 729], [[2267919, -10267965, 13178862, -13725855, 9813555, -6815826, 4494771, -3182814, 2164725, -1311669, 713466, -342663, 161046, -79776, 38283, -17655, 5391, -1334], 391473], [[-1548396, 10515096, -11391354, 12457152, -8587620, 6223878, -4036095, 2863026, -1934973, 1157724, -635502, 307902, -144630, 72705, -33081, 15849, -4615, 1435], 391473], [[-13122, -89667, 121014, -131220, 90882, -61479, 41175, -29592, 20673, -12501, 6699, -3201, 1476, -768, 369, -171, 49, -11], 2187], [[-258066, 11669832, -15774102, 18039591, -12841983, 8987598, -5902794, 4251744, -2957823, 1825434, -1003065, 485571, -227628, 114774, -55365, 26538, -8138, 2059], 391473], [[22565466, -44190522, 50939604, -43720074, 30554091, -20996010, 14401827, -10149921, 6595119, -3819834, 1991433, -949413, 461088, -227757, 107844, -43557, 12397, -2530], 391473], [[-10292751, 18381735, -22121019, 18480069, -13023963, 8781426, -6046578, 4258800, -2751468, 1594488, -819987, 389196, -188694, 92646, -44510, 17437, -5021, 853], 130491], [[1113183, -21926862, 26559657, -29072034, 20037861, -14070105, 9266751, -6608493, 4540365, -2739069, 1489641, -714645, 333828, -169890, 80073, -38019, 11051, -2964], 391473], [[11744919, -24616143, 28439991, -25042689, 17468703, -11979036, 8183052, -5749983, 3754026, -2179506, 1138587, -542742, 261534, -129453, 60936, -25138, 7184, -1499], 130491]]

hecke_ring_character_values = [[1459, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2189, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [0, 0, -1, 0, 0, 0, 1, 0, 0, 0, -1, 1, 0, 0, 0, 1, 0, 0], [0, 1, 0, -1, 0, 1, 0, -1, 0, 1, 0, 0, 0, 1, -1, 0, -1, 1], [-1, 1, 0, 0, -1, 0, 0, -1, -1, 0, 0, 0, 1, 0, 0, 1, 0, 0], [1, 0, 0, 0, -1, -1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0], [0, 1, 0, 2, 0, 1, 1, 0, 0, -1, 0, 0, 0, 1, 0, 0, 1, -1], [0, 0, 1, 0, 0, 0, 0, 0, -1, 0, -1, 0, 0, -1, -1, 0, -1, -1], [0, -1, -1, 0, 1, 0, 2, 1, 0, 1, 0, 1, -1, 0, 1, 0, -1, -1], [0, -1, 0, 0, 1, -1, 0, 0, 0, 1, 0, 0, -2, 0, 0, -1, 0, 0], [5, 0, 1, -1, 0, 0, 0, -2, 0, 1, 5, 0, 1, 0, -2, 0, -1, 0], [0, 0, 1, 0, 0, 0, -1, 0, -1, 0, 1, 0, 0, 1, -2, -1, 0, -1], [0, 0, 1, 0, 0, 0, 1, 0, 0, 0, -2, 2, 0, 1, 1, 0, 2, 0], [-4, 0, 0, 1, 0, 0, 0, 1, -1, 2, 0, 0, -1, 0, 0, 0, 0, 0], [3, 0, -1, 1, 0, 0, 3, 0, 0, 2, 3, 0, -1, 0, 0, 0, -2, 2], [0, 0, -1, 0, 0, 0, 1, 0, -1, 0, -2, 0, 0, 0, 1, 1, 2, -1], [2, 2, 2, -1, 0, -1, -1, -1, 0, 0, 2, 0, 2, -1, -1, 0, 0, 1], [-1, 1, 0, 1, -2, 1, 0, -2, 0, 1, 0, 0, -1, 0, 0, 1, 0, 0], [0, 1, 0, 0, 0, 0, 0, -1, 2, -1, 0, 0, 1, 0, 0, 1, 0, 0], [0, 0, -1, 0, 0, 0, 1, 0, -1, 0, 0, -1, 0, 0, 1, 2, -1, -1], [0, 0, 0, 0, 0, 0, 4, 0, 1, 0, -5, 2, 0, 0, 2, 0, 0, 1], [-7, 1, 0, 3, 0, 1, 0, 1, 0, -2, 0, 0, -1, 0, 0, 1, 0, 0], [0, 0, -1, 0, 0, 0, 1, 0, 0, 0, -2, 1, 0, 1, 3, 2, 1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -5, 2, 0, -1, -1, -2, -1, 2], [-1, -2, -2, 2, 2, 0, 3, 2, 0, -1, -1, 2, -2, 0, 2, 0, 1, 1], [-3, -1, 0, 4, -3, 1, 0, 1, 0, -2, 0, 0, 0, 0, 0, -1, 0, 0], [2, 1, 0, -4, -1, -1, 0, -3, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0], [4, -3, 0, 4, 1, 0, 2, 2, 0, -3, 4, 1, 0, 0, 2, 0, 3, -2], [-2, -2, 0, -1, 0, 1, 0, 1, -2, 0, 0, 0, -2, 0, 0, -2, 0, 0], [3, -2, 0, 3, -2, -1, 0, -1, 0, -1, 3, -2, 0, -1, -1, 0, 1, 0], [0, 0, 0, 0, 0, 0, -2, 0, 1, 0, -4, 3, 0, 1, -2, -1, 1, 1], [3, 0, 1, 0, -2, -4, -1, -3, 0, 1, 3, -2, 1, -4, -3, 0, -1, 0], [4, 4, 0, 0, 1, 1, 0, -1, 0, -1, 4, 1, 0, 1, -1, 0, 1, 3], [0, 0, 1, 0, 0, 0, 0, 0, 3, 0, -1, -3, 0, -1, 0, -1, -1, 3], [1, 2, 2, -5, 1, -2, -2, 0, 0, 2, 1, 1, 2, -2, 0, 0, -2, 3], [-3, -1, 0, 3, -2, 2, 0, 0, 3, 1, 0, 0, -2, 0, 0, -1, 0, 0], [0, 5, 2, 0, 1, 2, 1, -3, 0, 0, 0, 1, 2, 2, -3, 0, 0, 0], [0, 0, 3, 0, 0, 0, -3, 0, -3, 0, -8, -1, 0, 0, 1, 1, 5, -3], [-6, -4, 0, 3, -1, -2, 0, 4, 0, -2, 0, 0, -3, 0, 0, -4, 0, 0], [-3, 3, 0, 2, 1, 4, 0, 0, -3, -1, 0, 0, -1, 0, 0, 3, 0, 0], [0, 0, -3, 0, 0, 0, 5, 0, -1, 0, 2, 5, 0, 2, 0, -1, 1, -1], [1, 1, 1, -2, 2, 2, -2, -3, 0, -2, 1, 2, 1, 2, -3, 0, 2, 0], [-3, -1, 0, 0, 2, 2, 0, 0, -4, 1, 0, 0, 0, 0, 0, -1, 0, 0], [1, -1, 0, 4, -1, 0, 0, 0, 3, -3, 0, 0, 3, 0, 0, -1, 0, 0], [3, 2, -2, -2, 0, 0, 0, -1, 0, 2, 3, 0, -2, 0, -1, 0, -2, 1], [0, 0, -2, 0, 0, 0, 3, 0, 0, 0, 5, 1, 0, -1, -3, 2, -4, 0], [0, 0, 3, 0, 0, 0, -1, 0, -1, 0, 7, -1, 0, -3, -3, -1, -2, -1], [-3, -1, -1, 2, 3, 0, 3, 1, 0, -2, -3, 3, -1, 0, 1, 0, 2, -4], [1, 0, 0, -2, 0, -3, 0, -1, 3, 2, 0, 0, 2, 0, 0, 0, 0, 0], [1, -1, 2, 1, -4, -4, 0, -1, 0, 3, 1, -4, 2, -4, -1, 0, -3, 1], [0, 0, -2, 0, 0, 0, 0, 0, -1, 0, -1, -2, 0, 4, -2, -2, 0, -1], [2, 5, 0, -5, -3, -2, 0, -4, -2, 1, 0, 0, 3, 0, 0, 5, 0, 0], [1, 1, 2, 1, 1, -1, 0, 1, 0, -2, 1, 1, 2, -1, 1, 0, 2, 0], [0, 0, 0, 0, 0, 0, -1, 0, -1, 0, 3, 1, 0, 2, -5, -3, 0, -1], [-7, -5, 0, 0, 1, -2, 0, 1, -1, -1, 0, 0, 0, 0, 0, -5, 0, 0], [1, 1, 0, -2, 0, -5, 0, 1, 1, 0, 0, 0, 1, 0, 0, 1, 0, 0], [0, 0, -2, 0, 0, 0, 1, 0, 0, 0, -1, 6, 0, -1, 0, 2, 2, 0], [0, 0, -1, 0, 0, 0, 3, 0, -1, 0, -3, 0, 0, 3, 3, 0, -2, -1], [7, 2, 2, -7, -1, -2, -6, -3, 0, 2, 7, -1, 2, -2, -3, 0, -2, -3], [3, 1, 0, -3, 4, 1, -3, 3, 0, -4, 3, 4, 0, 1, 3, 0, 4, 2], [3, 0, 0, 0, -4, 1, 0, -1, -1, 4, 0, 0, 0, 0, 0, 0, 0, 0], [-8, -4, -1, 2, 0, -2, -1, 0, 0, -3, -8, 0, -1, -2, 0, 0, 3, -3], [0, 0, 3, 0, 0, 0, -4, 0, -1, 0, 5, -4, 0, -1, -2, -4, 1, -1], [0, 0, 2, 0, 0, 0, -4, 0, 5, 0, 3, 0, 0, -2, -2, -2, -3, 5], [0, 0, 0, 0, 0, 0, -6, 0, 2, 0, -3, -3, 0, -1, -2, -2, 1, 2], [0, 1, -1, 2, -2, -2, 2, 0, 0, 2, 0, -2, -1, -2, 0, 0, -2, 3], [-8, 2, 1, 1, -2, 1, -2, 0, 0, -1, -8, -2, 1, 1, 0, 0, 1, 2], [0, 0, 3, 0, 0, 0, -6, 0, 1, 0, 4, -1, 0, -2, -4, -4, -4, 1], [0, 0, 1, 0, 0, 0, -2, 0, 5, 0, -2, -3, 0, 2, -2, -4, -6, 5], [2, -1, 0, 6, -1, 3, 0, 6, 2, -5, 0, 0, 0, 0, 0, -1, 0, 0], [0, 0, 2, 0, 0, 0, 3, 0, 1, 0, 0, 5, 0, -1, -1, -2, 0, 1], [3, -3, -1, 1, -8, -7, -4, -1, 0, 3, 3, -8, -1, -7, -1, 0, -3, 1], [3, 6, 0, -2, 3, 4, 0, -3, -3, 2, 0, 0, 2, 0, 0, 6, 0, 0], [-8, -2, 2, 1, -2, -2, 0, 2, 0, 1, -8, -2, 2, -2, 2, 0, -1, 2], [0, 0, 0, 0, 0, 0, -7, 0, 4, 0, -2, -4, 0, 2, -5, -4, -2, 4], [3, 4, 0, -7, 1, 0, 0, -4, -4, 5, 0, 0, 4, 0, 0, 4, 0, 0], [-5, -7, -5, 3, 3, 3, 5, 4, 0, -1, -5, 3, -5, 3, 4, 0, 1, -5], [9, -7, -3, -7, -1, -6, -2, 0, 0, 6, 9, -1, -3, -6, 0, 0, -6, 0], [2, -1, 3, -2, -6, 3, -7, 0, 0, 1, 2, -6, 3, 3, 0, 0, -1, 4], [0, 0, 2, 0, 0, 0, -3, 0, -1, 0, -4, -2, 0, 3, -2, 0, -4, -1], [11, 2, 0, -1, 3, -2, 0, 2, 2, 0, 0, 0, -1, 0, 0, 2, 0, 0], [-2, -2, 0, -2, 2, 7, 0, 4, 1, -3, 0, 0, -2, 0, 0, -2, 0, 0], [0, 0, 3, 0, 0, 0, 0, 0, -2, 0, 0, 2, 0, 1, 5, -3, 5, -2], [0, 0, -4, 0, 0, 0, 4, 0, -4, 0, -1, -2, 0, -1, 4, 4, 6, -4], [2, -1, 0, -9, 2, -6, 0, -3, -7, 4, 0, 0, 0, 0, 0, -1, 0, 0], [0, 0, -5, 0, 0, 0, 9, 0, 3, 0, -1, 7, 0, -1, 0, 5, -4, 3], [0, 0, 1, 0, 0, 0, -5, 0, -5, 0, -3, -3, 0, -1, 2, -1, 0, -5], [-6, -3, -1, 11, 2, 2, 7, 5, 0, -6, -6, 2, -1, 2, 5, 0, 6, -5], [10, -5, 0, 1, 0, -1, 0, 4, 4, 0, 0, 0, -2, 0, 0, -5, 0, 0], [0, 0, 1, 0, 0, 0, 2, 0, -2, 0, 11, -2, 0, -2, 6, 0, 2, -2], [5, 1, 0, 1, -3, -1, 0, -1, -1, -3, 0, 0, -1, 0, 0, 1, 0, 0], [2, -1, 1, -2, -8, -7, -8, -2, 0, 2, 2, -8, 1, -7, -2, 0, -2, -2], [-5, 6, -3, 5, -4, 3, -2, -3, 0, -3, -5, -4, -3, 3, -3, 0, 3, 3], [9, 4, 0, -1, -2, 1, 0, -3, 0, -3, 0, 0, 7, 0, 0, 4, 0, 0], [1, 8, 5, -3, -5, 4, -8, -3, 0, 0, 1, -5, 5, 4, -3, 0, 0, 0], [4, 1, 0, -4, 3, -7, 0, 1, 2, 2, 0, 0, 0, 0, 0, 1, 0, 0], [-6, 7, 0, -2, 7, 3, 0, -1, -4, 2, 0, 0, -2, 0, 0, 7, 0, 0], [-1, -2, 0, 5, 6, 2, 0, 1, 7, -7, 0, 0, 0, 0, 0, -2, 0, 0], [0, 0, 0, 0, 0, 0, 4, 0, -3, 0, -10, -1, 0, 3, 3, 0, 6, -3], [-4, 1, 0, 2, 8, 7, 0, 1, -3, -2, 0, 0, -1, 0, 0, 1, 0, 0], [-1, 5, -1, -1, -3, 5, -7, -2, 0, -3, -1, -3, -1, 5, -2, 0, 3, -1], [0, 0, 4, 0, 0, 0, -11, 0, -3, 0, 1, -12, 0, 0, -6, -1, 3, -3], [-1, 1, -1, 1, -5, 0, -9, 1, 0, -5, -1, -5, -1, 0, 1, 0, 5, -4], [-9, 0, 0, -7, 7, 7, 0, -4, -1, -2, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, -6, 0, 0, 0, 13, -5, 0, -6, -3, 2, 0, 0], [-5, 4, 0, 0, 4, 5, 0, 4, -1, -4, 0, 0, 3, 0, 0, 4, 0, 0], [-10, 0, -6, -2, 1, -2, -1, 0, 0, 0, -10, 1, -6, -2, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 2, 0, -2, 0, -3, 7, 0, 0, -4, -1, -2, -2], [-6, 0, 1, -8, 2, -1, -8, 0, 0, -2, -6, 2, 1, -1, 0, 0, 2, 0], [5, 5, 0, -11, -6, -2, 0, -12, -3, 2, 0, 0, 5, 0, 0, 5, 0, 0], [-13, 1, 0, -4, 3, -4, -2, 0, 0, -1, -13, 3, 0, -4, 0, 0, 1, -1], [0, 0, 0, 0, 0, 0, 4, 0, -2, 0, -3, -2, 0, 1, -7, 0, -4, -2], [-1, 0, 0, 1, -5, 0, 0, 1, -2, 4, 0, 0, -4, 0, 0, 0, 0, 0], [0, 0, -2, 0, 0, 0, -5, 0, -4, 0, -11, -3, 0, 5, 1, 2, 6, -4], [-2, -3, -3, -4, 2, -6, 1, 0, 0, 3, -2, 2, -3, -6, 0, 0, -3, -3], [15, -4, 0, 2, 2, -2, 0, 1, -4, 2, 0, 0, 1, 0, 0, -4, 0, 0], [0, 3, 9, -3, -9, -2, -12, -4, 0, 0, 0, -9, 9, -2, -4, 0, 0, 1], [0, 0, 1, 0, 0, 0, 2, 0, 5, 0, 0, -7, 0, 6, -5, -10, -6, 5], [14, -2, 7, 4, -8, -6, -5, -4, 0, -1, 14, -8, 7, -6, -4, 0, 1, -5], [0, 0, -3, 0, 0, 0, -1, 0, 0, 0, -8, 6, 0, 3, 6, 1, 3, 0], [0, 0, -5, 0, 0, 0, 1, 0, -1, 0, 8, 1, 0, -6, 6, 7, 1, -1], [0, -2, 0, -11, 1, -1, 0, -4, -5, 1, 0, 0, -1, 0, 0, -2, 0, 0], [0, 0, 4, 0, 0, 0, 3, 0, 2, 0, -2, 8, 0, -2, 1, -4, 0, 2], [5, 5, 0, -2, -1, -6, 0, 0, -3, 0, 0, 0, 2, 0, 0, 5, 0, 0], [0, 0, 5, 0, 0, 0, 0, 0, 9, 0, 4, -4, 0, 4, -3, -4, 1, 9], [13, -2, 0, -2, 0, -5, 0, 5, -1, 0, 0, 0, -2, 0, 0, -2, 0, 0], [0, 0, 3, 0, 0, 0, -7, 0, 6, 0, 2, -8, 0, 3, -3, -12, -3, 6], [-14, 5, -4, -1, -1, 7, -3, -3, 0, -1, -14, -1, -4, 7, -3, 0, 1, -3], [14, 4, 0, -7, -4, -7, 0, -6, 6, 1, 0, 0, 4, 0, 0, 4, 0, 0], [-8, 4, -1, -3, -3, -4, 1, -5, 0, 7, -8, -3, -1, -4, -5, 0, -7, 3], [1, 7, 5, -4, -3, -4, 2, -7, 0, 9, 1, -3, 5, -4, -7, 0, -9, 4], [-8, 0, 0, -1, -3, 2, 0, 4, 4, -1, 0, 0, 0, 0, 0, 0, 0, 0], [-3, 5, 1, -6, 3, 10, -1, -2, 0, 2, -3, 3, 1, 10, -2, 0, -2, 4], [-2, 2, -2, 4, -1, -2, 0, 10, 0, -3, -2, -1, -2, -2, 10, 0, 3, 2], [-11, 1, 0, 1, 12, 10, 0, 5, 5, -9, 0, 0, -5, 0, 0, 1, 0, 0], [9, 6, -3, 3, 1, 5, 9, -5, 0, 5, 9, 1, -3, 5, -5, 0, -5, 5], [-3, -2, -7, -3, 12, 2, 13, 5, 0, 4, -3, 12, -7, 2, 5, 0, -4, 2], [-2, 2, 0, -5, -1, 7, 0, -3, 3, -3, 0, 0, 8, 0, 0, 2, 0, 0], [7, -5, 0, 1, -10, -5, 0, -2, 4, 6, 0, 0, 4, 0, 0, -5, 0, 0], [0, 0, 5, 0, 0, 0, -5, 0, -4, 0, 7, -9, 0, -8, 2, -1, 2, -4], [1, -3, -1, 2, -11, 0, -5, -5, 0, 4, 1, -11, -1, 0, -5, 0, -4, -4], [3, -7, 0, 4, -1, 1, 0, 7, 4, 3, 0, 0, -1, 0, 0, -7, 0, 0], [11, -5, 0, -1, 4, -1, 0, 2, -4, 9, 0, 0, -7, 0, 0, -5, 0, 0], [0, 0, 5, 0, 0, 0, -12, 0, 0, 0, -4, -3, 0, 5, -1, 0, 10, 0], [0, 0, 3, 0, 0, 0, 3, 0, -1, 0, -2, -2, 0, -4, -2, -3, -5, -1], [0, 0, 3, 0, 0, 0, -6, 0, -7, 0, 6, -1, 0, 0, -4, -8, -1, -7], [-1, 7, 5, -5, -2, 9, -3, -2, 0, 4, -1, -2, 5, 9, -2, 0, -4, 5], [-5, -5, 0, 9, 0, 1, 0, 2, 4, -8, 0, 0, -10, 0, 0, -5, 0, 0], [-4, -6, -5, 1, 9, 10, 7, 1, 0, -3, -4, 9, -5, 10, 1, 0, 3, -7], [-13, -10, 0, 6, 4, -3, 0, 9, 3, 0, 0, 0, -4, 0, 0, -10, 0, 0], [-7, 1, 0, 1, 12, 11, 0, 2, -4, -3, 0, 0, -1, 0, 0, 1, 0, 0], [-15, 3, -1, -11, 9, 4, 3, -7, 0, 5, -15, 9, -1, 4, -7, 0, -5, 6], [0, 0, -3, 0, 0, 0, -11, 0, 2, 0, -6, -4, 0, -7, 1, 1, 1, 2], [0, 0, 1, 0, 0, 0, 2, 0, 4, 0, 11, -2, 0, -2, -3, -3, -10, 4], [12, 0, 0, -16, 4, 4, 0, -10, -4, 10, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 5, 0, 0, 0, -3, 0, 10, 0, 3, 0, 0, -4, -8, -6, -8, 10], [-5, -4, 0, 2, -1, -6, 0, 5, -1, -1, 0, 0, -5, 0, 0, -4, 0, 0], [14, -1, 1, -5, -2, 5, -5, -8, 0, 2, 14, -2, 1, 5, -8, 0, -2, 4], [0, 0, 4, 0, 0, 0, 3, 0, 1, 0, 9, 2, 0, 10, 1, -2, 1, 1], [-2, 1, 0, -7, 0, -3, 0, 0, -8, 2, 0, 0, 0, 0, 0, 1, 0, 0], [11, -3, -3, -6, 5, -5, 6, 2, 0, 7, 11, 5, -3, -5, 2, 0, -7, -5], [-3, -6, 0, 6, -7, -7, 0, 4, 8, -4, 0, 0, 2, 0, 0, -6, 0, 0], [2, 0, 2, 0, 11, 0, 7, 4, 0, -4, 2, 11, 2, 0, 4, 0, 4, 4], [0, 0, 1, 0, 0, 0, 2, 0, -10, 0, 6, 2, 0, -3, -2, 5, 0, -10], [-6, -4, 0, 10, -1, -1, 0, -4, 2, 0, 0, 0, -4, 0, 0, -4, 0, 0], [0, 0, 3, 0, 0, 0, -10, 0, -5, 0, 0, -3, 0, 4, 2, 6, 8, -5], [-9, 6, 0, 10, -6, 1, 0, -4, -1, -5, 0, 0, 6, 0, 0, 6, 0, 0], [-14, -13, -9, 10, 0, -1, 5, 8, 0, -5, -14, 0, -9, -1, 8, 0, 5, -4], [0, 0, -4, 0, 0, 0, 8, 0, -6, 0, -26, -5, 0, 0, 5, 3, -2, -6], [0, -3, -3, 0, -8, -7, -3, 1, 0, 5, 0, -8, -3, -7, 1, 0, -5, 2], [-10, -5, 3, 11, -3, -7, -2, 3, 0, -10, -10, -3, 3, -7, 3, 0, 10, -4], [0, 0, -1, 0, 0, 0, 8, 0, 1, 0, -5, 0, 0, -7, 2, 3, 0, 1], [4, 2, -2, 12, 7, 1, 16, 7, 0, -3, 4, 7, -2, 1, 7, 0, 3, -7], [11, 0, 5, -3, -7, -9, -8, -2, 0, 2, 11, -7, 5, -9, -2, 0, -2, -5], [0, 0, 4, 0, 0, 0, -9, 0, 4, 0, 6, -6, 0, 6, -4, -4, -2, 4], [0, -4, 0, -3, -1, -6, 0, -1, -2, 7, 0, 0, 3, 0, 0, -4, 0, 0], [-5, -3, 0, -11, 3, -1, 0, 0, -3, 7, 0, 0, -2, 0, 0, -3, 0, 0], [0, 0, -2, 0, 0, 0, -7, 0, 2, 0, -2, 3, 0, -2, -2, 2, 6, 2], [0, 0, 2, 0, 0, 0, -6, 0, 5, 0, -4, -2, 0, 3, -8, 0, -4, 5], [0, 0, -4, 0, 0, 0, -3, 0, 1, 0, -27, -2, 0, -2, 3, -1, 5, 1], [-6, -6, 3, -5, -1, -1, -10, 1, 0, -4, -6, -1, 3, -1, 1, 0, 4, 2], [6, 4, 0, 0, 1, 3, 0, -2, -4, -4, 0, 0, 0, 0, 0, 4, 0, 0], [10, 1, -4, -3, 9, -2, 10, -1, 0, 4, 10, 9, -4, -2, -1, 0, -4, 8], [0, 0, -5, 0, 0, 0, 4, 0, -2, 0, -13, -6, 0, 0, -1, 5, -3, -2], [0, 7, 0, -2, -5, 0, 0, -1, 5, -1, 0, 0, -2, 0, 0, 7, 0, 0], [0, 0, 5, 0, 0, 0, 4, 0, 4, 0, -5, -8, 0, 2, -4, -3, -9, 4], [-17, 4, 3, -11, 4, 8, -8, -5, 0, -1, -17, 4, 3, 8, -5, 0, 1, -4], [6, 3, 0, 3, 6, 2, 0, 1, -5, 0, 0, 0, 0, 0, 0, 3, 0, 0], [8, 8, 0, -6, -6, 1, 0, -10, -1, 4, 0, 0, 3, 0, 0, 8, 0, 0], [0, 0, -6, 0, 0, 0, 9, 0, -7, 0, -11, 4, 0, -6, 0, 11, 1, -7], [9, -9, 0, -8, 6, -8, 0, -3, -6, 8, 0, 0, -4, 0, 0, -9, 0, 0], [0, 0, -1, 0, 0, 0, 9, 0, -1, 0, 1, 10, 0, 1, -7, -7, -1, -1], [-8, 11, 0, -3, -1, -4, 0, -1, -8, 1, 0, 0, 6, 0, 0, 11, 0, 0], [5, 10, 3, -6, -5, 4, -6, -2, 0, 5, 5, -5, 3, 4, -2, 0, -5, 10], [-9, 3, 5, -6, 3, -4, -9, -1, 0, -6, -9, 3, 5, -4, -1, 0, 6, 4], [0, 0, 1, 0, 0, 0, -2, 0, 8, 0, 9, -7, 0, 4, 1, -6, -3, 8], [0, 0, 3, 0, 0, 0, -5, 0, 1, 0, -10, 8, 0, 2, -7, -3, -3, 1], [4, -6, 0, 5, -6, -15, 0, 2, 4, 1, 0, 0, 4, 0, 0, -6, 0, 0], [27, 4, 4, 1, -3, -5, -8, -6, 0, -6, 27, -3, 4, -5, -6, 0, 6, -6], [0, 0, 1, 0, 0, 0, -10, 0, -8, 0, -1, -4, 0, 12, -1, -6, 1, -8], [-14, -6, -4, 11, 4, 0, 7, 1, 0, -8, -14, 4, -4, 0, 1, 0, 8, 2], [0, 0, 3, 0, 0, 0, 10, 0, -2, 0, -12, 10, 0, 1, 14, 6, 5, -2], [-25, 3, 0, -14, -2, -5, 0, -9, -3, 9, 0, 0, 0, 0, 0, 3, 0, 0], [-1, -9, 0, 13, -8, -10, 0, -1, 5, -3, 0, 0, -3, 0, 0, -9, 0, 0], [-4, -2, 0, 12, -7, 11, 0, 2, 2, -6, 0, 0, -4, 0, 0, -2, 0, 0], [25, -2, 0, -8, -4, -4, -1, -11, 0, 11, 25, -4, 0, -4, -11, 0, -11, 7], [0, 0, 1, 0, 0, 0, -2, 0, -9, 0, -4, -1, 0, -6, 4, 12, 11, -9], [4, -4, 0, 2, 1, -2, -2, -1, 0, -5, 4, 1, 0, -2, -1, 0, 5, 4], [-3, 0, 0, 9, -7, 10, 0, -3, 0, -7, 0, 0, 5, 0, 0, 0, 0, 0], [5, -6, -1, 6, -1, 0, 4, 4, 0, -1, 5, -1, -1, 0, 4, 0, 1, -2], [0, 0, -3, 0, 0, 0, 3, 0, 1, 0, -24, -1, 0, 10, -1, -6, 2, 1], [0, 0, 0, 0, 0, 0, 1, 0, -4, 0, 11, 6, 0, -7, -6, -1, -5, -4], [7, 5, 12, 4, -3, 3, -4, -5, 0, -5, 7, -3, 12, 3, -5, 0, 5, -6], [0, 0, -1, 0, 0, 0, -10, 0, 4, 0, -3, -3, 0, -4, 2, 1, 3, 4], [-21, -7, -7, -5, 11, 3, 1, 4, 0, -5, -21, 11, -7, 3, 4, 0, 5, -1], [0, 0, 0, 0, 0, 0, 6, 0, -6, 0, -19, 10, 0, 3, -1, 5, 4, -6], [20, 3, 0, 11, -11, -6, 0, -8, 2, -1, 0, 0, 11, 0, 0, 3, 0, 0], [-9, -3, -9, 16, 4, 13, 14, 8, 0, -6, -9, 4, -9, 13, 8, 0, 6, 1], [7, -1, 4, -1, 0, 4, -10, 7, 0, -9, 7, 0, 4, 4, 7, 0, 9, -1], [0, -3, -3, 8, 0, -1, 7, 1, 0, -1, 0, 0, -3, -1, 1, 0, 1, -10], [20, -4, -6, 14, -11, -7, 4, -2, 0, 1, 20, -11, -6, -7, -2, 0, -1, -3], [-12, 10, 0, -4, -8, 0, 0, -1, -4, 2, 0, 0, 1, 0, 0, 10, 0, 0], [11, 2, 2, 0, 7, 14, 10, 1, 0, 3, 11, 7, 2, 14, 1, 0, -3, -1], [0, 0, 1, 0, 0, 0, 9, 0, 8, 0, -3, 6, 0, -2, -2, 3, -12, 8], [0, 0, 3, 0, 0, 0, 4, 0, 5, 0, 7, -3, 0, -3, -3, -1, -11, 5], [-21, 6, 0, 10, -1, 5, 0, 1, 6, -2, 0, 0, 1, 0, 0, 6, 0, 0], [0, 0, 7, 0, 0, 0, -8, 0, 4, 0, 10, -11, 0, 3, -10, -2, -2, 4], [0, 0, 11, 0, 0, 0, -12, 0, 0, 0, 9, -11, 0, -12, -11, -4, -4, 0], [8, 7, 5, -16, 2, -3, -16, -2, 0, -2, 8, 2, 5, -3, -2, 0, 2, 2], [10, 1, 0, 2, 0, 1, 0, 4, -11, 0, 0, 0, -8, 0, 0, 1, 0, 0], [1, 8, -1, -4, -7, 4, 0, -3, 0, 11, 1, -7, -1, 4, -3, 0, -11, 6], [2, 9, 3, 0, 3, 11, 3, -1, 0, 0, 2, 3, 3, 11, -1, 0, 0, 4], [0, 0, -2, 0, 0, 0, 5, 0, -3, 0, 24, 13, 0, -1, -3, 7, -4, -3], [0, 0, -1, 0, 0, 0, -5, 0, 3, 0, -5, 11, 0, -3, 5, -6, 4, 3], [4, -5, -6, -4, 8, -7, 6, 1, 0, 2, 4, 8, -6, -7, 1, 0, -2, -1], [19, 0, 0, -3, -5, -8, 0, 1, 0, -2, 0, 0, -2, 0, 0, 0, 0, 0], [20, -3, 1, 10, -10, 10, -5, 3, 0, -5, 20, -10, 1, 10, 3, 0, 5, 1], [-21, 7, 0, 5, 12, 13, 0, 6, -8, -4, 0, 0, -6, 0, 0, 7, 0, 0], [0, 0, -7, 0, 0, 0, 11, 0, 1, 0, -32, 1, 0, -8, 7, 15, -5, 1], [-1, -1, 0, -14, 9, -14, 0, -6, -3, 11, 0, 0, -1, 0, 0, -1, 0, 0], [2, 2, -7, 3, -2, -1, 10, 2, 0, 9, 2, -2, -7, -1, 2, 0, -9, -2], [-6, -14, 0, -8, 10, -15, 0, 2, -7, 2, 0, 0, -5, 0, 0, -14, 0, 0], [15, 5, -3, -13, 10, 4, 4, -5, 0, 7, 15, 10, -3, 4, -5, 0, -7, 12], [0, 0, -6, 0, 0, 0, 12, 0, -4, 0, -8, 9, 0, 4, 10, -6, 6, -4], [-5, 3, 0, 4, 3, 8, 0, 0, 9, -2, 0, 0, 4, 0, 0, 3, 0, 0], [20, 0, 1, -7, 3, -9, 0, 4, 0, 4, 20, 3, 1, -9, 4, 0, -4, 12], [-28, 2, 2, 0, -1, 11, -4, 5, 0, -3, -28, -1, 2, 11, 5, 0, 3, -5], [-20, 9, 0, 8, -2, 11, 0, 3, -5, 2, 0, 0, -1, 0, 0, 9, 0, 0], [3, -3, 6, 8, -9, -1, -5, -2, 0, -4, 3, -9, 6, -1, -2, 0, 4, -10], [-12, -12, 0, 8, -7, 9, 0, 3, 0, 3, 0, 0, -12, 0, 0, -12, 0, 0], [-1, -10, -1, -5, 14, -12, 12, 6, 0, 3, -1, 14, -1, -12, 6, 0, -3, 0], [0, 0, -10, 0, 0, 0, 6, 0, -3, 0, -13, 6, 0, 4, 0, 1, -2, -3], [0, 0, 0, 0, 0, 0, 6, 0, 8, 0, -33, 2, 0, 9, 5, -8, 5, 8], [-19, -1, 0, -10, 9, 7, 0, -1, -4, 0, 0, 0, -10, 0, 0, -1, 0, 0], [-6, 1, 0, 4, -2, 0, 0, -4, 2, 5, 0, 0, -8, 0, 0, 1, 0, 0], [0, 0, -2, 0, 0, 0, 3, 0, -1, 0, 25, -1, 0, -8, -2, 2, -12, -1], [8, 7, 0, 3, 3, -10, 0, -6, 2, 1, 0, 0, 5, 0, 0, 7, 0, 0], [9, -5, 0, 19, 0, -6, 0, 5, 11, -7, 0, 0, -5, 0, 0, -5, 0, 0], [0, 0, 3, 0, 0, 0, -2, 0, -2, 0, -7, 3, 0, -8, -7, -5, 5, -2], [0, 0, -5, 0, 0, 0, 8, 0, 0, 0, 5, 9, 0, -2, 2, 1, 4, 0], [17, 12, 12, 5, -17, 1, -17, -4, 0, -5, 17, -17, 12, 1, -4, 0, 5, -2], [4, -6, 0, 12, -2, 5, 0, 5, -1, -3, 0, 0, -1, 0, 0, -6, 0, 0], [0, 5, -1, 2, 9, 1, 14, -2, 0, 3, 0, 9, -1, 1, -2, 0, -3, 8], [0, 0, -8, 0, 0, 0, -1, 0, -10, 0, 1, -3, 0, -11, 7, 8, 3, -10], [2, 8, 0, 9, -13, 5, 0, 1, 3, -8, 0, 0, 3, 0, 0, 8, 0, 0], [0, 0, -1, 0, 0, 0, -3, 0, 9, 0, -2, -2, 0, 2, -5, 5, -10, 9], [-12, 8, -1, -8, 2, 9, 1, -2, 0, 7, -12, 2, -1, 9, -2, 0, -7, 8], [-5, -5, -1, 5, -4, 8, -1, 7, 0, -2, -5, -4, -1, 8, 7, 0, 2, -6], [13, 5, 0, 0, -10, 1, 0, -4, 0, 10, 13, -10, 0, 1, -4, 0, -10, -8], [31, 1, 0, -11, -6, -8, 0, -1, -1, 1, 0, 0, 3, 0, 0, 1, 0, 0], [0, 0, 1, 0, 0, 0, 2, 0, 1, 0, 21, 7, 0, 3, -4, -10, 1, 1], [34, 13, 13, -7, -6, -10, -9, -15, 0, 4, 34, -6, 13, -10, -15, 0, -4, -3], [23, -1, 8, -16, -2, -10, -9, -7, 0, 9, 23, -2, 8, -10, -7, 0, -9, 1], [-1, -13, 0, 3, 5, -11, 0, 9, 3, -1, 0, 0, -13, 0, 0, -13, 0, 0], [-8, 6, 5, -5, -3, 10, -6, -17, 0, 2, -8, -3, 5, 10, -17, 0, -2, 1], [0, 0, 4, 0, 0, 0, -16, 0, -5, 0, -6, -11, 0, -15, 2, 5, 4, -5], [7, 13, 0, 7, 5, 7, 0, 1, 1, -12, 0, 0, 4, 0, 0, 13, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 10, 0, -17, -8, 0, -1, 1, -4, -8, 10], [-8, -4, -2, 9, 6, 0, 5, 4, 0, -10, -8, 6, -2, 0, 4, 0, 10, -14], [-12, -4, -13, -3, 7, 3, 2, -2, 0, -2, -12, 7, -13, 3, -2, 0, 2, 2], [0, 0, 1, 0, 0, 0, -15, 0, -6, 0, 1, 2, 0, 2, -7, -5, -8, -6], [0, 0, -8, 0, 0, 0, 23, 0, 6, 0, -31, 7, 0, 11, 12, -1, -1, 6], [-5, -5, -5, 0, -8, 14, -7, -6, 0, 1, -5, -8, -5, 14, -6, 0, -1, 6], [7, 7, 0, -1, -7, 11, 0, -11, -9, -2, 0, 0, 8, 0, 0, 7, 0, 0], [-13, -2, 0, 6, 8, 8, 0, 11, -4, -3, 0, 0, -4, 0, 0, -2, 0, 0], [-21, 6, 4, 2, -6, 8, -3, -11, 0, 1, -21, -6, 4, 8, -11, 0, -1, -3], [0, 0, 0, 0, 0, 0, -16, 0, 13, 0, -6, 0, 0, 1, -10, -9, -7, 13], [-24, -6, 0, -2, -6, -13, 0, 1, -1, 2, 0, 0, 2, 0, 0, -6, 0, 0], [0, 0, 9, 0, 0, 0, 1, 0, -10, 0, -4, 2, 0, -9, 4, 0, 3, -10], [16, -2, 0, 4, 8, -8, 0, 2, 6, -1, 0, 0, -9, 0, 0, -2, 0, 0], [-22, -10, -6, 3, -1, -2, 0, 14, 0, -2, -22, -1, -6, -2, 14, 0, 2, 2], [3, 17, 2, -4, 0, 8, -7, 0, 0, -3, 3, 0, 2, 8, 0, 0, 3, -3], [0, 0, 3, 0, 0, 0, -2, 0, 9, 0, -1, 2, 0, -3, 9, -3, -3, 9], [21, -1, -6, 1, -3, 1, -4, -8, 0, -2, 21, -3, -6, 1, -8, 0, 2, -6], [0, 0, -4, 0, 0, 0, 6, 0, 13, 0, 11, 7, 0, -16, 2, 5, -9, 13], [0, 0, -2, 0, 0, 0, -3, 0, -8, 0, 9, -6, 0, 3, -3, 3, 5, -8], [-22, 9, 0, -16, -2, -10, 0, -7, -12, 5, 0, 0, 5, 0, 0, 9, 0, 0], [0, 0, 2, 0, 0, 0, -5, 0, 1, 0, 35, 6, 0, -16, -4, 8, -3, 1], [-5, -5, -6, -1, -7, -1, -3, -5, 0, 5, -5, -7, -6, -1, -5, 0, -5, 2], [15, -5, 0, 13, -11, 5, 0, -4, 7, 4, 0, 0, -7, 0, 0, -5, 0, 0], [12, 13, 0, -9, -13, -12, 0, -13, -10, 17, 0, 0, 4, 0, 0, 13, 0, 0]]
